@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011 Motorola Mobility, Inc. All rights reserved.
+ * Copyright (c) 2011 Motorola Mobility, Inc.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
@@ -38,27 +38,11 @@
 G_BEGIN_DECLS
 
 #define WEBKIT_TYPE_SETTINGS            (webkit_settings_get_type())
-#define WEBKIT_SETTINGS(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_SETTINGS, WebKitSettings))
-#define WEBKIT_SETTINGS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_SETTINGS, WebKitSettingsClass))
-#define WEBKIT_IS_SETTINGS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_SETTINGS))
-#define WEBKIT_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_SETTINGS))
-#define WEBKIT_SETTINGS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_SETTINGS, WebKitSettingsClass))
-
-struct _WebKitSettingsClass {
-    GObjectClass parent_class;
-
-    /*< private >*/
-    void (*_webkit_reserved0) (void);
-    void (*_webkit_reserved1) (void);
-    void (*_webkit_reserved2) (void);
-    void (*_webkit_reserved3) (void);
-};
 
 WEBKIT_DECLARE_FINAL_TYPE (WebKitSettings, webkit_settings, WEBKIT, SETTINGS, GObject)
 
 /**
  * WebKitHardwareAccelerationPolicy:
- * @WEBKIT_HARDWARE_ACCELERATION_POLICY_ON_DEMAND: Hardware acceleration is enabled/disabled as request by web contents.
  * @WEBKIT_HARDWARE_ACCELERATION_POLICY_ALWAYS: Hardware acceleration is always enabled, even for websites not requesting it.
  * @WEBKIT_HARDWARE_ACCELERATION_POLICY_NEVER: Hardware acceleration is always disabled, even for websites requesting it.
  *
@@ -67,7 +51,6 @@ WEBKIT_DECLARE_FINAL_TYPE (WebKitSettings, webkit_settings, WEBKIT, SETTINGS, GO
  * Since: 2.16
  */
 typedef enum {
-    WEBKIT_HARDWARE_ACCELERATION_POLICY_ON_DEMAND,
     WEBKIT_HARDWARE_ACCELERATION_POLICY_ALWAYS,
     WEBKIT_HARDWARE_ACCELERATION_POLICY_NEVER
 } WebKitHardwareAccelerationPolicy;
@@ -100,10 +83,10 @@ WEBKIT_DEPRECATED void
 webkit_settings_set_load_icons_ignoring_image_load_setting     (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_DEPRECATED gboolean
+WEBKIT_API gboolean
 webkit_settings_get_enable_offline_web_application_cache       (WebKitSettings *settings);
 
-WEBKIT_DEPRECATED void
+WEBKIT_API void
 webkit_settings_set_enable_offline_web_application_cache       (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -120,33 +103,6 @@ webkit_settings_get_enable_html5_database                      (WebKitSettings *
 WEBKIT_API void
 webkit_settings_set_enable_html5_database                      (WebKitSettings *settings,
                                                                 gboolean        enabled);
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_xss_auditor                         (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_xss_auditor                         (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_frame_flattening                    (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_frame_flattening                    (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_plugins                             (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_plugins                             (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_java                                (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_java                                (WebKitSettings *settings,
-                                                                gboolean        enabled);
 
 WEBKIT_API gboolean
 webkit_settings_get_javascript_can_open_windows_automatically  (WebKitSettings *settings);
@@ -155,10 +111,10 @@ WEBKIT_API void
 webkit_settings_set_javascript_can_open_windows_automatically  (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_DEPRECATED gboolean
+WEBKIT_API gboolean
 webkit_settings_get_enable_hyperlink_auditing                  (WebKitSettings *settings);
 
-WEBKIT_DEPRECATED void
+WEBKIT_API void
 webkit_settings_set_enable_hyperlink_auditing                  (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -239,12 +195,6 @@ WEBKIT_API void
 webkit_settings_set_default_charset                            (WebKitSettings *settings,
                                                                 const gchar    *default_charset);
 
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_private_browsing                    (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_private_browsing                    (WebKitSettings *settings,
-                                                                gboolean        enabled);
 
 WEBKIT_API gboolean
 webkit_settings_get_enable_developer_extras                    (WebKitSettings *settings);
@@ -267,10 +217,10 @@ WEBKIT_API void
 webkit_settings_set_enable_tabs_to_links                       (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_DEPRECATED gboolean
+WEBKIT_API gboolean
 webkit_settings_get_enable_dns_prefetching                     (WebKitSettings *settings);
 
-WEBKIT_DEPRECATED void
+WEBKIT_API void
 webkit_settings_set_enable_dns_prefetching                     (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -382,19 +332,6 @@ WEBKIT_API void
 webkit_settings_set_enable_smooth_scrolling                    (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_accelerated_2d_canvas               (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_accelerated_2d_canvas               (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_API gboolean
-webkit_settings_get_enable_2d_canvas_acceleration              (WebKitSettings *settings);
-
-WEBKIT_API void
-webkit_settings_set_enable_2d_canvas_acceleration              (WebKitSettings *settings,
-                                                                gboolean        enabled);
 
 WEBKIT_API gboolean
 webkit_settings_get_enable_write_console_messages_to_stdout    (WebKitSettings *settings);
@@ -542,19 +479,6 @@ webkit_settings_get_experimental_features                      (void);
 WEBKIT_API WebKitFeatureList *
 webkit_settings_get_development_features                       (void);
 
-WEBKIT_API gboolean
-webkit_settings_apply_from_key_file                            (WebKitSettings  *settings,
-                                                                GKeyFile        *key_file,
-                                                                const gchar     *group_name,
-                                                                GError         **error);
-
-WEBKIT_API const gchar*
-webkit_settings_get_webrtc_udp_ports_range                     (WebKitSettings *settings);
-
-WEBKIT_API void
-webkit_settings_set_webrtc_udp_ports_range                     (WebKitSettings *settings,
-                                                                const gchar    *udp_port_range);
-
 G_END_DECLS
 
 #endif /* WebKitSettings_h */
